@@ -11,6 +11,10 @@ WebhookTypesLiterals = Literal[
     'account.update',
     'entity.update',
     'entity.create',
+    'payment_reversal.create',
+    'payment_reversal.update',
+    'connection.create',
+    'connection.update',
     'account_verification.create',
     'account_verification.update',
     'account_verification.sent',
